uni project

Fork of BSP_DISCO_F746NG by ST

Files at this revision

API Documentation at this revision

Comitter:
valadore
Date:
Wed Mar 29 10:07:34 2017 +0000
Parent:
7:fe313c53cdb5
Commit message:
updating audio bsp to simultaneous in-out

Changed in this revision

Drivers/BSP/STM32746G-Discovery/stm32746g_discovery_audio.c Show annotated file Show diff for this revision Revisions of this file
diff -r fe313c53cdb5 -r 891071f1cf9a Drivers/BSP/STM32746G-Discovery/stm32746g_discovery_audio.c
--- a/Drivers/BSP/STM32746G-Discovery/stm32746g_discovery_audio.c	Thu Nov 10 10:05:52 2016 +0100
+++ b/Drivers/BSP/STM32746G-Discovery/stm32746g_discovery_audio.c	Wed Mar 29 10:07:34 2017 +0000
@@ -881,8 +881,9 @@
   uint32_t deviceid = 0x00;
   uint32_t slot_active;
 
-  if (InputDevice != INPUT_DEVICE_DIGITAL_MICROPHONE_2)  /* Only MICROPHONE_2 input supported */
-  {
+  if ((InputDevice != INPUT_DEVICE_INPUT_LINE_1) &&       /* Only INPUT_LINE_1 and MICROPHONE_2 inputs supported */
+      (InputDevice != INPUT_DEVICE_DIGITAL_MICROPHONE_2))
+      {
     ret = AUDIO_ERROR;
   }
   else